"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KnapsackHtmlRenderer = void 0;
const renderers_1 = require("@knapsack/app/renderers");
const types_1 = require("@knapsack/types");
const file_utils_1 = require("@knapsack/file-utils");
const path_1 = require("path");
const { pkg } = (0, file_utils_1.findUpPkgJson)(__dirname);
const gitRoot = (0, file_utils_1.findGitRoot)();
class KnapsackHtmlRenderer extends renderers_1.RendererBase {
    constructor({ codeSrcs, } = {}) {
        super({
            id: types_1.rendererIds.html,
            language: 'html',
            codeSrcsUserConfig: codeSrcs,
        });
        this.render = async (opt) => {
            try {
                const usage = await this.getUsage(opt);
                return {
                    ok: true,
                    html: await (0, file_utils_1.formatCode)({
                        contents: usage,
                        path: 'x.html',
                    }),
                };
            }
            catch (e) {
                return {
                    ok: false,
                    html: `<p>${e.message}</p>`,
                    message: e.message,
                };
            }
        };
        this.getUsage = async ({ demo, state }) => {
            var _a;
            const path = demo.type === 'template'
                ? demo.templateInfo.path
                : (_a = this.normalizeDemo({ demo, state })) === null || _a === void 0 ? void 0 : _a.codeSrcPath;
            if (!path) {
                throw new Error(`No path found for demo: ${JSON.stringify(demo)}`);
            }
            const { absolutePath, exists } = await this.resolvePath(path);
            if (!exists) {
                throw new Error(`File does not exist: ${absolutePath}`);
            }
            return (0, file_utils_1.readFile)(absolutePath);
        };
        this.getDiscovery = async () => {
            return {
                rendererId: this.id,
                meta: this.getMeta(),
                codeSrcsByPath: Object.fromEntries(this.codeSrcs.entries()),
                templates: this.getCodeSrcs().map(({ path }) => (0, types_1.addIdToTemplateInfo)({
                    codeSrcPath: path,
                    rendererId: this.id,
                })),
            };
        };
        this.getTemplateSuggestions = async ({ state, }) => {
            const { unusedPaths } = await this.getUnusedTemplatePaths({
                globPaths: [(0, path_1.join)(gitRoot, '**/*.html')],
                state,
            });
            return {
                suggestions: unusedPaths.map((path) => ({
                    path,
                })),
            };
        };
        this.getMeta = () => ({
            id: this.id,
            title: 'HTML',
            syntaxHighlightingLanguage: 'html',
            aliasUse: 'off',
            enableDataDemos: false,
            enableTemplateDemos: true,
            hasSlotsSupport: false,
            version: pkg.version,
            hasInferSpecSupport: false,
            hasTemplateSuggestionsSupport: true,
        });
    }
}
exports.KnapsackHtmlRenderer = KnapsackHtmlRenderer;
//# sourceMappingURL=index.js.map